$if 0
          Eq2PrUs - Function: Equivalent To Print Using Numeric
--------------------------------------------------------------------------


Purpose:  Provides the equivalent of a PRINT USING "##...##", except the
          end result is placed into a string variable rather than to a
          device.


Syntax:   Equal2printUSEnumber$( value , length , decimals )

          value    - any numeric value (DBL,SNG,LNG,INT) with a total
                     maximum precision of 15 significant digits either side
                     of the decimal.

          length   - the total length of the end result. Numbers are right
                     set and left-padded with spaces.

          decimals - the quantity of decimal places to be included.


Function: Returns a string equivalent to a PRINT USING call.


Remarks:  This function is valid for upto 15 significant places, meaning
          dollar-&-cents values to $99billion/99cents.

          The function will round up/down in the same manner as the PRINT
          USING command.

          CAUTION: When using PRINT USING any value requireing a quantity
          of character positions in excess of the specified USING string
          will cause the complete number to output prefixed with a "%"
          character.

          HOWEVER: This function does not allow for the "%" character
          notification. It assumes that total length is the priority
          factor. Specifically, If a value requires more character spaces
          than specified then the returning value is truncated.


Usage:    This function is totally self contained and does not use any
          other user defined procedures or functions. It uses only locally
          declared variables and does not modify the incomming value,
          length or decimals variable.


Example:           PRINT USING "####.##"; 12.6
                   PRINT Equal2printUSEnumber$( 12.6,7,2)

                   PRINT USING "#########.###";  4567.0005
                   PRINT Equal2printUSEnumber$(4567.0005,13,3)

                   PRINT USING "###.###";  (-12.0004)
                   PRINT Equal2printUSEnumber$(-12.0004,7,3)

           RUN ...   12.60
                     12.60
                        4567.001
                        4567.001
                   -12.000
                   -12.000


$endif

$compile unit

$error all-
$lib all-

defint a-z



Function Equal2printUSEnumber$(X#,P%,D%) Public
   LOCAL T$,L%,Z%,S%
   S%=SGN(X#)
   T$=STR$(FIX((X#*(10^D%))+((.5)*S%)))
   T$=RIGHT$(T$,LEN(T$)-1)
   L%=LEN(T$)
   Z%=D%-L%
   Z%=((ABS(Z%>0))*Z%)
   T$=STRING$(Z%,"0")+T$
   L%=LEN(T$)
   T$=LEFT$("-",ABS(S%=(-1)))+LEFT$(T$,L%-D%)+LEFT$("0",(ABS((L%-D%)=0)))+ _
      LEFT$(".",D%)+RIGHT$(T$,D%)
   equal2printUSEnumber$=RIGHT$(SPACE$(P%)+T$,P%)
END Function
